summaryrefslogtreecommitdiff
path: root/src/httpfetch.h
diff options
context:
space:
mode:
authorLejo <Lejo_1@web.de>2020-07-30 00:16:21 +0300
committerGitHub <noreply@github.com>2020-07-29 23:16:21 +0200
commit715a123a33db7b0f191259ba68cbc9c565d0d4e8 (patch)
tree5925cc93ad339477d58dcea42bcf79b62e2ded5d /src/httpfetch.h
parentf34abaedd2b9277c1862cd9b82ca3338747f104e (diff)
downloadminetest-715a123a33db7b0f191259ba68cbc9c565d0d4e8.tar.gz
minetest-715a123a33db7b0f191259ba68cbc9c565d0d4e8.tar.bz2
minetest-715a123a33db7b0f191259ba68cbc9c565d0d4e8.zip
Add PUT and DELETE request + specific method value to HTTP API (#9909)
Diffstat (limited to 'src/httpfetch.h')
-rw-r--r--src/httpfetch.h22
1 files changed, 17 insertions, 5 deletions
diff --git a/src/httpfetch.h b/src/httpfetch.h
index ae8b5afb5..3b9f17f0a 100644
--- a/src/httpfetch.h
+++ b/src/httpfetch.h
@@ -28,6 +28,15 @@ with this program; if not, write to the Free Software Foundation, Inc.,
#define HTTPFETCH_DISCARD 0
#define HTTPFETCH_SYNC 1
+// Methods
+enum HttpMethod : u8
+{
+ HTTP_GET,
+ HTTP_POST,
+ HTTP_PUT,
+ HTTP_DELETE,
+};
+
struct HTTPFetchRequest
{
std::string url = "";
@@ -50,12 +59,15 @@ struct HTTPFetchRequest
// application/x-www-form-urlencoded. POST-only.
bool multipart = false;
- // POST fields. Fields are escaped properly.
- // If this is empty a GET request is done instead.
- StringMap post_fields;
+ // The Method to use default = GET
+ // Avaible methods GET, POST, PUT, DELETE
+ HttpMethod method = HTTP_GET;
+
+ // Fields of the request
+ StringMap fields;
- // Raw POST data, overrides post_fields.
- std::string post_data;
+ // Raw data of the request overrides fields
+ std::string raw_data;
// If not empty, should contain entries such as "Accept: text/html"
std::vector<std::string> extra_headers;